/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

import org.junit.runner.Description;
import org.junit.runner.Result;
import org.junit.runner.notification.Failure;
import org.junit.runner.notification.RunListener;

import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.rdf.model.Property;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.vocabulary.DCTerms;
import com.hp.hpl.jena.vocabulary.RDF;


@SuppressWarnings({"rawtypes","unchecked"})
public class EarlJunitRunListener extends RunListener {
	private Model model = null;
	private String subject = null;
	private String testUrl = null;

	private Property earlResult = null;
	private Property earlOutcome = null;
	private Property earlSubject =  null;
	private Property earlTest = null;

	public EarlJunitRunListener()  {
		this.model = ModelFactory.createDefaultModel();
		this.earlResult = this.model.createProperty("http://www.w3.org/ns/earl#", "result");
		this.earlOutcome = this.model.createProperty("http://www.w3.org/ns/earl#", "outcome");
		this.earlSubject = this.model.createProperty("http://www.w3.org/ns/earl#", "subject");
		this.earlTest = this.model.createProperty("http://www.w3.org/ns/earl#", "test");
	}

	public void setSubject(String currentSubject) {
		this.subject = currentSubject;
	}

	public Model getModel() {
		return this.model;
	}

	public void testStarted(Description description) {
		this.testUrl = null;
	}

	public void testFinished(Description description) {
		try {
			Class testClass = Class.forName(description.getClassName());
			Method testMethod = testClass.getMethod(description.getMethodName());

			if(testMethod.isAnnotationPresent(EarlTestCase.class))
				this.testUrl = ((EarlTestCase)testMethod.getAnnotation(EarlTestCase.class)).url();
		} catch (Exception e) {}
	}

	public void testRunFinished(Result result) {
		if(this.testUrl == null)
			return;

		String outcome = result.wasSuccessful() ? "http://www.w3.org/ns/earl#passed" : "http://www.w3.org/ns/earl#failed";

		ArrayList<String> descriptions = new ArrayList<String>();

		for(Failure failure : result.getFailures()) {
			Throwable throwable = failure.getException();

			if(throwable.getMessage() != null && !throwable.getMessage().isEmpty())
				descriptions.add(throwable.getMessage());
		}

		createAssertion(this.testUrl, outcome, descriptions);
	}

	private void createAssertion(String testUrl, String outcome, List<String> descriptions) {
		Resource testResult = null;

		testResult = this.model.createResource()
				.addProperty(RDF.type, this.model.createResource("http://www.w3.org/ns/earl#TestResult"))
				.addProperty(this.earlOutcome, this.model.createResource(outcome));

		for(String description : descriptions)
			testResult.addProperty(DCTerms.description, description);

		model.createResource()
			.addProperty(RDF.type, this.model.createResource("http://www.w3.org/ns/earl#Assertion"))
			.addProperty(this.earlResult, testResult)
			.addProperty(this.earlSubject, this.model.createResource(this.subject))
			.addProperty(this.earlTest, this.model.createResource(testUrl));
	}
}
