/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test.webid.testcases;

import org.bergnet.test.EarlTestCase;
import org.junit.Assert;
import org.junit.Test;


public class MissingFOAF extends AbstractTestCase {
	public MissingFOAF() throws Exception {
		id = "missingfoaf.rdf";
		verificationQuery = "PREFIX earl: <http://www.w3.org/ns/earl#>\n" +
				"PREFIX wit: <http://www.w3.org/2005/Incubator/webid/earl/RelyingParty#>\n" +
				"ASK WHERE {\n" +
				"	?profileGetAssertion\n" +
				"		earl:test wit:profileGet;\n" +
				"		earl:result ?profileGetResult;\n" +
				"		earl:subject ?webid.\n" +
				"	?profileGetResult earl:outcome earl:failed.\n" +
				"	?webidAuthenticationAssertion\n" +
				"		earl:test wit:webidAuthentication;\n" +
				"		earl:result ?webidAuthenticationResult.\n" +
				"	?webidAuthenticationResult earl:outcome earl:failed }";

		init();
	}

	@EarlTestCase(
			url="http://www.w3.org/2005/Incubator/webid/earl/TestSuite#missingFoaf",
			title="Does the endpoint detect a missing FOAF file?",
			description="Use a valid certificate and private key for authentication, but don't publish the FOAF file 404 http error).")
	@Test
	public void test() throws Exception {
		generateWebID();
		login();
		verifyOutput();

		Assert.assertTrue(result);
	}
}
