/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.webid.commons;

import java.security.SecureRandom;

import javax.net.ssl.KeyManager;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;

import org.apache.http.conn.scheme.Scheme;
import org.apache.http.conn.ssl.AllowAllHostnameVerifier;
import org.apache.http.conn.ssl.SSLSocketFactory;
import org.apache.http.impl.client.DefaultHttpClient;
import org.bergnet.test.webid.TrustAllTrustManager;
import org.bergnet.test.webid.WebIDClientKeyManager;


public class WebIDHttpClient extends DefaultHttpClient {
	public WebIDHttpClient(WebID webid) throws WebIDException {
		init(webid, 443);
	}

	public WebIDHttpClient(WebID webid, int port) throws WebIDException {
		init(webid, port);
	}

	private void init(WebID webid, int port) throws WebIDException {
		try {
			SSLContext sslContext = SSLContext.getInstance("TLS");
			sslContext.init(
					new KeyManager[] { new WebIDClientKeyManager(webid) },
					new TrustManager[] { new TrustAllTrustManager() }, // TODO: built in X509 trust manager and configure CAs
					new SecureRandom());

			//TODO: verifier
			//SSLSocketFactory sslSocketFactory = new SSLSocketFactory(sslContext);
			SSLSocketFactory sslSocketFactory = new SSLSocketFactory(sslContext, new AllowAllHostnameVerifier());

			Scheme scheme = new Scheme("https", port, sslSocketFactory);
			getConnectionManager().getSchemeRegistry().register(scheme);
			//this.getConnectionManager().
		} catch(Exception e) {
			throw new WebIDException("error during initialization of WebIDHttpClient", e);
		}
	}
}
